{inputs, ...}: {
  imports = with inputs; [
    nix-flatpak.homeManagerModules.nix-flatpak
  ];
  services.flatpak = {
    enable = true;
    uninstallUnmanaged = true;
    remotes = [
      {
        name = "flathub";
        location = "https://dl.flathub.org/repo/flathub.flatpakrepo";
      }
      {
        name = "hero-persson";
        location = "https://hero-persson.github.io/unmojang-flatpak/index.flatpakrepo";
      }
    ];
    packages = [
      # misc
      "app.zen_browser.zen"
      "net.mullvad.MullvadBrowser"
      "com.obsproject.Studio"
      "com.bitwarden.desktop"
      "com.github.tchx84.Flatseal"
      "org.qbittorrent.qBittorrent"

      # "com.transmissionbt.Transmission"
      "com.usebottles.bottles"
      "com.logseq.Logseq"
      "io.github.martchus.syncthingtray"

      # chatting
      "org.signal.Signal"
      "im.riot.Riot"
      "org.telegram.desktop"
      "io.github.spacingbat3.webcord"
      "org.mozilla.Thunderbird"

      # media
      "org.atheme.audacious"
      "io.freetubeapp.FreeTube"
      #"io.github.celluloid_player.Celluloid"
      # "io.mpv.Mpv"

      # gaming
      #"com.github._0negal.Viper"
      "net.lutris.Lutris"
      "com.heroicgameslauncher.hgl"
      {
        appId = "org.unmojang.FjordLauncher";
        origin = "hero-persson";
      }
      "org.freedesktop.Platform.VulkanLayer.MangoHud//24.08"
      "org.freedesktop.Platform.VulkanLayer.gamescope//24.08"
    ];
    overrides = {
      "global" = {
        # Force Wayland by default
        Context = {
          sockets = ["wayland" "!x11" "!fallback-x11"];
          filesystems = [
            "xdg-run/pipewire-0"
            "xdg-config/gtk-3.0:ro"
            "xdg-config/gtk-4.0:ro"
            # "~/.local/share/fonts:ro"
            "~/.local/share/icons:ro"
            # "~/.nix-profile/share/icons:ro"
            # "~/.nix-profile/share/fonts:ro"
            "/nix/store:ro"
          ];
        };
        Environment = {
          XCURSOR_PATH = "/run/host/user-share/icons:/run/host/share/icons";
          ELECTRON_OZONE_PLATFORM_HINT = "wayland";
          #GTK_THEME = "adw-gtk3";
        };
      };
      "io.github.martchus.syncthingtray".Context.filesystems = ["/storage/games/heroic/Factorio/game/saves"];
      "org.octave.Octave".Context.sockets = ["x11"];
      "org.octave.Octave".Environment = {QT_QPA_PLATFORM = "xcb";};
      "com.valvesoftware.Steam" = {
        Context = {
          sockets = ["x11" "wayland"];
          filesystems = ["/storage/games/steam"];
        };
        Environment = {
          STEAM_FORCE_DESKTOPUI_SCALING = "1.3";
        };
      };
      "org.signal.Signal" = {
        Environment = {
          SIGNAL_PASSWORD_STORE = "gnome-libsecret";
        };
      };
      "net.lutris.Lutris".Context = {
        sockets = ["x11" "wayland"];
        filesystems = ["/storage/games/lutris" "~/games/lutris"];
      };
      "com.heroicgameslauncher.hgl".Context = {
        sockets = ["x11" "wayland"];
        filesystems = ["/storage/games/heroic" "~/games/heroic"];
      };
      "com.usebottles.Bottles" = {
        Context = {
          sockets = ["x11" "wayland"];
          filesystems = ["/home/user/docs/nure/tex-template/assets/BridgeKSG"];
        };
      };
    };
  };
}
