{
  perSystem,
  config,
  pkgs,
  lib,
  ...
}:
with lib; let
  cfg = config.desktop.hyprland;
in {
  imports = [./common/pipewire.nix];
  options = {
    desktop.hyprland.enable =
      mkEnableOption "enable hyprland desktop";
  };
  config = mkIf cfg.enable {
    programs.hyprland = {
      enable = true;
      package = perSystem.hyprland.hyprland;
      portalPackage = perSystem.hyprland.xdg-desktop-portal-hyprland;
    };
    environment.systemPackages = with pkgs; [
      brightnessctl
      gcr_4
    ];
    fonts.fontDir.enable = true;
    security.pam = {
      services.hyprlock = {};
      loginLimits = [
        {
          domain = "@users";
          item = "rtprio";
          type = "-";
          value = 1;
        }
      ];
    };
    services = {
      gnome.gnome-keyring.enable = true;
      udisks2.enable = true;
      dbus = {
        apparmor = "enabled";
        implementation = "broker";
      };
    };
    programs = {
      dconf.enable = true;
      seahorse.enable = true;
    };
    xdg.portal = {
      enable = true;
      extraPortals = [
        perSystem.hyprland.xdg-desktop-portal-hyprland
        pkgs.xdg-desktop-portal-gtk
      ];
      config.common.default = [
        "hyprland"
        "gtk"
      ];
    };

    programs.regreet.enable = true;
    services.greetd = {
      enable = true;
      vt = 6;
      settings = {
        default_session = {
          command = "${pkgs.cage}/bin/cage -s -m last -- ${pkgs.greetd.regreet}/bin/regreet";
        };
        initial_session = {
          user = "user";
          command = "Hyprland";
        };
      };
    };
  };
}
